@@ -1,5 +1,5 @@
 """Sub-classes for vtk.vtkRectilinearGrid and vtk.vtkImageData."""
-import logging
+from functools import wraps
 import pathlib
 from typing import Sequence, Tuple, Union
 import warnings
@@ -9,13 +9,10 @@ import numpy as np
 import pyvista
 from pyvista import _vtk
 from pyvista.core.dataset import DataSet
-from pyvista.core.filters import UniformGridFilters, _get_output
-from pyvista.utilities import abstract_class
+from pyvista.core.filters import RectilinearGridFilters, UniformGridFilters, _get_output
+from pyvista.utilities import abstract_class, assert_empty_kwargs
 import pyvista.utilities.helpers as helpers
-from pyvista.utilities.misc import PyvistaDeprecationWarning, raise_has_duplicates
-
-log = logging.getLogger(__name__)
-log.setLevel('CRITICAL')
+from pyvista.utilities.misc import PyVistaDeprecationWarning, raise_has_duplicates
 
 
 @abstract_class
@@ -38,7 +35,7 @@ class Grid(DataSet):
         Create a uniform grid with dimensions ``(1, 2, 3)``.
 
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(2, 3, 4))
+        >>> grid = pyvista.UniformGrid(dimensions=(2, 3, 4))
         >>> grid.dimensions
         (2, 3, 4)
         >>> grid.plot(show_edges=True)
@@ -64,7 +61,7 @@ class Grid(DataSet):
         return attrs
 
 
-class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
+class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
     """Dataset with variable spacing in the three coordinate directions.
 
     Can be initialized in several ways:
@@ -95,6 +92,10 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         ``False``. If ``True``, an error is raised if there are any duplicate
         values in any of the array-valued input arguments.
 
+    deep : bool, optional
+        Whether to deep copy a ``vtk.vtkRectilinearGrid`` object.
+        Default is ``False``.  Keyword only.
+
     Examples
     --------
     >>> import pyvista
@@ -116,18 +117,22 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     >>> yrng = np.arange(-10, 10, 5)
     >>> zrng = np.arange(-10, 10, 1)
     >>> grid = pyvista.RectilinearGrid(xrng, yrng, zrng)
+    >>> grid.plot(show_edges=True)
 
     """
 
     _WRITERS = {'.vtk': _vtk.vtkRectilinearGridWriter, '.vtr': _vtk.vtkXMLRectilinearGridWriter}
 
-    def __init__(self, *args, check_duplicates=False, **kwargs):
+    def __init__(self, *args, check_duplicates=False, deep=False, **kwargs):
         """Initialize the rectilinear grid."""
         super().__init__()
 
         if len(args) == 1:
             if isinstance(args[0], _vtk.vtkRectilinearGrid):
-                self.deep_copy(args[0])
+                if deep:
+                    self.deep_copy(args[0])
+                else:
+                    self.shallow_copy(args[0])
             elif isinstance(args[0], (str, pathlib.Path)):
                 self._from_file(args[0], **kwargs)
             elif isinstance(args[0], np.ndarray):
@@ -190,14 +195,22 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         # Must at least be an x array
         if check_duplicates:
             raise_has_duplicates(x)
+
+        # edges are shown as triangles if x is not floating point
+        if not np.issubdtype(x.dtype, np.floating):
+            x = x.astype(float)
         self.SetXCoordinates(helpers.convert_array(x.ravel()))
         if y is not None:
             if check_duplicates:
                 raise_has_duplicates(y)
+            if not np.issubdtype(y.dtype, np.floating):
+                y = y.astype(float)
             self.SetYCoordinates(helpers.convert_array(y.ravel()))
         if z is not None:
             if check_duplicates:
                 raise_has_duplicates(z)
+            if not np.issubdtype(z.dtype, np.floating):
+                z = z.astype(float)
             self.SetZCoordinates(helpers.convert_array(z.ravel()))
         # Ensure dimensions are properly set
         self._update_dimensions()
@@ -394,13 +407,16 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         ``vtk.vtkImageData``. Use keyword arguments to specify the
         dimensions, spacing, and origin of the uniform grid.
 
+    .. versionchanged:: 0.37.0
+        The ``dims`` parameter has been renamed to ``dimensions``.
+
     Parameters
     ----------
     uinput : str, vtk.vtkImageData, pyvista.UniformGrid, optional
         Filename or dataset to initialize the uniform grid from.  If
         set, remainder of arguments are ignored.
 
-    dims : iterable, optional
+    dimensions : iterable, optional
         Dimensions of the uniform grid.
 
     spacing : iterable, optional
@@ -410,6 +426,10 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
     origin : iterable, optional
         Origin of the uniform grid.  Defaults to ``(0.0, 0.0, 0.0)``.
 
+    deep : bool, optional
+        Whether to deep copy a ``vtk.vtkImageData`` object.
+        Default is ``False``.  Keyword only.
+
     Examples
     --------
     Create an empty UniformGrid.
@@ -426,19 +446,19 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
     Initialize using using just the grid dimensions and default
     spacing and origin. These must be keyword arguments.
 
-    >>> grid = pyvista.UniformGrid(dims=(10, 10, 10))
+    >>> grid = pyvista.UniformGrid(dimensions=(10, 10, 10))
 
     Initialize using dimensions and spacing.
 
     >>> grid = pyvista.UniformGrid(
-    ...     dims=(10, 10, 10),
+    ...     dimensions=(10, 10, 10),
     ...     spacing=(2, 1, 5),
     ... )
 
     Initialize using dimensions, spacing, and an origin.
 
     >>> grid = pyvista.UniformGrid(
-    ...     dims=(10, 10, 10),
+    ...     dimensions=(10, 10, 10),
     ...     spacing=(2, 1, 5),
     ...     origin=(10, 35, 50),
     ... )
@@ -446,7 +466,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
     Initialize from another UniformGrid.
 
     >>> grid = pyvista.UniformGrid(
-    ...     dims=(10, 10, 10),
+    ...     dimensions=(10, 10, 10),
     ...     spacing=(2, 1, 5),
     ...     origin=(10, 35, 50),
     ... )
@@ -459,31 +479,48 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
     _WRITERS = {'.vtk': _vtk.vtkDataSetWriter, '.vti': _vtk.vtkXMLImageDataWriter}
 
     def __init__(
-        self, uinput=None, *args, dims=None, spacing=(1.0, 1.0, 1.0), origin=(0.0, 0.0, 0.0)
+        self,
+        uinput=None,
+        *args,
+        dimensions=None,
+        spacing=(1.0, 1.0, 1.0),
+        origin=(0.0, 0.0, 0.0),
+        deep=False,
+        **kwargs,
     ):
         """Initialize the uniform grid."""
         super().__init__()
 
         # permit old behavior
         if isinstance(uinput, Sequence) and not isinstance(uinput, str):
+            # Deprecated on v0.37.0, estimated removal on v0.40.0
             warnings.warn(
                 "Behavior of pyvista.UniformGrid has changed. First argument must be "
                 "either a ``vtk.vtkImageData`` or path.",
-                PyvistaDeprecationWarning,
+                PyVistaDeprecationWarning,
             )
-            dims = uinput
+            dimensions = uinput
             uinput = None
 
+        if dimensions is None and 'dims' in kwargs:
+            dimensions = kwargs.pop('dims')
+            # Deprecated on v0.37.0, estimated removal on v0.40.0
+            warnings.warn(
+                '`dims` argument is deprecated. Please use `dimensions`.', PyVistaDeprecationWarning
+            )
+        assert_empty_kwargs(**kwargs)
+
         if args:
+            # Deprecated on v0.37.0, estimated removal on v0.40.0
             warnings.warn(
                 "Behavior of pyvista.UniformGrid has changed. Use keyword arguments "
                 "to specify dimensions, spacing, and origin. For example:\n\n"
                 "    >>> grid = pyvista.UniformGrid(\n"
-                "    ...     dims=(10, 10, 10),\n"
+                "    ...     dimensions=(10, 10, 10),\n"
                 "    ...     spacing=(2, 1, 5),\n"
                 "    ...     origin=(10, 35, 50),\n"
                 "    ... )\n",
-                PyvistaDeprecationWarning,
+                PyVistaDeprecationWarning,
             )
             origin = args[0]
             if len(args) > 1:
@@ -497,7 +534,10 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         # first argument must be either vtkImageData or a path
         if uinput is not None:
             if isinstance(uinput, _vtk.vtkImageData):
-                self.deep_copy(uinput)
+                if deep:
+                    self.deep_copy(uinput)
+                else:
+                    self.shallow_copy(uinput)
             elif isinstance(uinput, (str, pathlib.Path)):
                 self._from_file(uinput)
             else:
@@ -506,13 +546,13 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
                     f"or a path, not {type(uinput)}.  Use keyword arguments to "
                     "specify dimensions, spacing, and origin. For example:\n\n"
                     "    >>> grid = pyvista.UniformGrid(\n"
-                    "    ...     dims=(10, 10, 10),\n"
+                    "    ...     dimensions=(10, 10, 10),\n"
                     "    ...     spacing=(2, 1, 5),\n"
                     "    ...     origin=(10, 35, 50),\n"
                     "    ... )\n"
                 )
-        elif dims is not None:
-            self._from_specs(dims, spacing, origin)
+        elif dimensions is not None:
+            self._from_specs(dimensions, spacing, origin)
 
     def __repr__(self):
         """Return the default representation."""
@@ -559,7 +599,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Examples
         --------
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(2, 2, 2))
+        >>> grid = pyvista.UniformGrid(dimensions=(2, 2, 2))
         >>> grid.points
         array([[0., 0., 0.],
                [1., 0., 0.],
@@ -607,7 +647,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Examples
         --------
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(2, 2, 2))
+        >>> grid = pyvista.UniformGrid(dimensions=(2, 2, 2))
         >>> grid.x
         array([0., 1., 0., 1., 0., 1., 0., 1.])
 
@@ -621,7 +661,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Examples
         --------
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(2, 2, 2))
+        >>> grid = pyvista.UniformGrid(dimensions=(2, 2, 2))
         >>> grid.y
         array([0., 0., 1., 1., 0., 0., 1., 1.])
 
@@ -635,7 +675,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Examples
         --------
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(2, 2, 2))
+        >>> grid = pyvista.UniformGrid(dimensions=(2, 2, 2))
         >>> grid.z
         array([0., 0., 0., 0., 1., 1., 1., 1.])
 
@@ -649,7 +689,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Examples
         --------
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(5, 5, 5))
+        >>> grid = pyvista.UniformGrid(dimensions=(5, 5, 5))
         >>> grid.origin
         (0.0, 0.0, 0.0)
 
@@ -696,7 +736,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Create a 5 x 5 x 5 uniform grid.
 
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(5, 5, 5))
+        >>> grid = pyvista.UniformGrid(dimensions=(5, 5, 5))
         >>> grid.spacing
         (1.0, 1.0, 1.0)
         >>> grid.plot(show_edges=True)
@@ -776,7 +816,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         Create a ``UniformGrid`` and show its extent.
 
         >>> import pyvista
-        >>> grid = pyvista.UniformGrid(dims=(10, 10, 10))
+        >>> grid = pyvista.UniformGrid(dimensions=(10, 10, 10))
         >>> grid.extent
         (0, 9, 0, 9, 0, 9)
 
@@ -801,3 +841,8 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         if len(new_extent) != 6:
             raise ValueError('Extent must be a vector of 6 values.')
         self.SetExtent(new_extent)
+
+    @wraps(RectilinearGridFilters.to_tetrahedra)
+    def to_tetrahedra(self, *args, **kwargs):
+        """Cast to a rectangular grid and then convert to tetrahedra."""
+        return self.cast_to_rectilinear_grid().to_tetrahedra(*args, **kwargs)
