@@ -46,13 +46,20 @@ def buffer_normals(trimesh):
 
 
 def get_coloring(mapper, dataset):
-    """Return the three.js coloring type for a given actor."""
+    """Return the three.js coloring type for a given actor.
+
+    Returns
+    -------
+    str
+        Either ``'NoColors'``, ``'VertexColors'``, or ``'FaceColors'``.
+
+    """
     coloring = 'NoColors'
-    if mapper.GetScalarModeAsString() == 'UsePointData':
+    if mapper.scalar_map_mode == 'point':
         scalars = dataset.point_data.active_scalars
         if scalars is not None:
             coloring = 'VertexColors'
-    elif mapper.GetScalarModeAsString() == 'UseCellData':
+    elif mapper.scalar_map_mode == 'cell':
         scalars = dataset.cell_data.active_scalars
         if scalars is not None:
             coloring = 'FaceColors'
@@ -91,15 +98,15 @@ def extract_surface_mesh(obj):
     return mesh
 
 
-def map_scalars(mapper, scalars):
+def map_scalars(lookup_table, scalars):
     """Map scalars to a RGB array.
 
     Parameters
     ----------
-    mapper : vtk.vtkMapper
-        Mapper containing lookup table.
+    lookup_table : vtk.vtkLookupTable
+        Color lookup table.
     scalars : vtk array, numpy.ndarray, or pyvista.pyvista_ndarray
-        Scalars to map
+        Scalars to map.
 
     Returns
     -------
@@ -112,9 +119,7 @@ def map_scalars(mapper, scalars):
             scalars = scalars.VTKObject
         else:
             scalars = pv._vtk.numpy_to_vtk(scalars)
-
-    table = mapper.GetLookupTable()
-    return pv.wrap(table.MapScalars(scalars, 0, 0))[:, :3] / 255
+    return pv.wrap(lookup_table.MapScalars(scalars, 0, 0))[:, :3] / 255
 
 
 def array_to_float_buffer(points):
@@ -144,7 +149,18 @@ def cast_to_min_size(ind, max_index):
     return tjs.BufferAttribute(array=ind, normalized=False)
 
 
-def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
+def to_surf_mesh(
+    surf,
+    texture,
+    prop,
+    scalar_mode,
+    color_mode,
+    lookup_table,
+    coloring,
+    add_attr=None,
+    color=None,
+    opacity=None,
+):
     """Convert a pyvista surface to a buffer geometry.
 
     General Notes
@@ -167,6 +183,9 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
     * MeshBasicMaterial when lighting is disabled.
 
     """
+    # allow override of property opacity
+    opacity = prop.GetOpacity() if opacity is None else opacity
+
     if add_attr is None:
         add_attr = {}
     # convert to an all-triangular surface
@@ -190,19 +209,18 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
 
     # extract point/cell scalars for coloring
     colors = None
-    scalar_mode = mapper.GetScalarModeAsString()
     if scalar_mode == 'UsePointData':
-        colors = map_scalars(mapper, trimesh.point_data.active_scalars)
+        colors = map_scalars(lookup_table, trimesh.point_data.active_scalars)
     elif scalar_mode == 'UseCellData':
         # special handling for RGBA
-        if mapper.GetColorMode() == 2:
+        if color_mode == 2:
             scalars = trimesh.cell_data.active_scalars.repeat(3, axis=0)
             scalars = scalars.astype(np.float32, copy=False)
             colors = scalars[:, :3] / 255  # ignore alpha
         else:
             # must repeat for each triangle
             scalars = trimesh.cell_data.active_scalars.repeat(3)
-            colors = map_scalars(mapper, scalars)
+            colors = map_scalars(lookup_table, scalars)
 
         position = array_to_float_buffer(trimesh.points[face_ind])
         attr = {'position': position}
@@ -230,7 +248,6 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
     surf_geo = tjs.BufferGeometry(attributes=attr)
 
     # add texture to the surface buffer if available
-    texture = actor.GetTexture()
     tjs_texture = None
     if texture is not None:
         wrapped_tex = pv.wrap(texture.GetInput())
@@ -246,22 +263,30 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
 
     # these attributes are always used regardless of the material
     shared_attr = {
-        'vertexColors': get_coloring(mapper, trimesh),
+        'vertexColors': coloring,
         'wireframe': prop.GetRepresentation() == 1,
-        'opacity': prop.GetOpacity(),
+        'opacity': opacity,
         'wireframeLinewidth': prop.GetLineWidth(),
         # 'side': 'DoubleSide'  # enabling seems to mess with textures
     }
 
     if colors is None:
-        shared_attr['color'] = pv.Color(prop.GetColor()).hex_rgb
+        if color is None:
+            shared_attr['color'] = pv.Color(prop.GetColor()).hex_rgb
+        else:
+            shared_attr['color'] = pv.Color(color).hex_rgb
 
     if tjs_texture is not None:
         shared_attr['map'] = tjs_texture
     else:
-        shared_attr['side'] = 'DoubleSide'
+        if prop.GetBackfaceCulling():
+            shared_attr['side'] = 'FrontSide'
+        elif prop.GetFrontfaceCulling():
+            shared_attr['side'] = 'BackSide'
+        else:
+            shared_attr['side'] = 'DoubleSide'
 
-    if prop.GetOpacity() < 1.0:
+    if opacity < 1.0:
         shared_attr['transparent'] = True
 
     if prop.GetInterpolation() == 3:  # using physically based rendering
@@ -289,7 +314,17 @@ def to_surf_mesh(actor, surf, mapper, prop, add_attr=None):
     return tjs.Mesh(geometry=surf_geo, material=material)
 
 
-def to_edge_mesh(surf, mapper, prop, use_edge_coloring=True, use_lines=False):
+def to_edge_mesh(
+    surf,
+    prop,
+    coloring,
+    scalar_mode,
+    lookup_table,
+    use_edge_coloring=True,
+    use_lines=False,
+    color=None,
+    opacity=None,
+):
     """Convert a pyvista surface to a three.js edge mesh."""
     # extract all edges from the surface.  Should not use triangular
     # mesh here as mesh may contain more than triangular faces
@@ -306,11 +341,10 @@ def to_edge_mesh(surf, mapper, prop, use_edge_coloring=True, use_lines=False):
     }
 
     # add in colors
-    coloring = get_coloring(mapper, surf)
     if coloring != 'NoColors' and not use_edge_coloring:
-        if mapper.GetScalarModeAsString() == 'UsePointData':
+        if scalar_mode == 'UsePointData':
             edge_scalars = edges_mesh.point_data.active_scalars
-            edge_colors = map_scalars(mapper, edge_scalars)
+            edge_colors = map_scalars(lookup_table, edge_scalars)
             attr['color'] = array_to_float_buffer(edge_colors)
 
     edge_geo = tjs.BufferGeometry(attributes=attr)
@@ -321,36 +355,42 @@ def to_edge_mesh(surf, mapper, prop, use_edge_coloring=True, use_lines=False):
 
     if use_edge_coloring:
         edge_color = prop.GetEdgeColor()
+    elif color is not None:
+        edge_color = color
     else:
         edge_color = prop.GetColor()
 
+    opacity = prop.GetOpacity() if opacity is None else opacity
     edge_mat = tjs.LineBasicMaterial(
         color=pv.Color(edge_color).hex_rgb,
         linewidth=prop.GetLineWidth(),
-        opacity=prop.GetOpacity(),
+        opacity=opacity,
         side='FrontSide',
         **mesh_attr,
     )
     return tjs.LineSegments(edge_geo, edge_mat)
 
 
-def to_tjs_points(dataset, mapper, prop):
+def to_tjs_points(dataset, prop, coloring, lookup_table, color=None, opacity=None):
     """Extract the points from a dataset and return a buffered geometry."""
     attr = {
         'position': array_to_float_buffer(dataset.points),
     }
 
-    coloring = get_coloring(mapper, dataset)
     if coloring == 'VertexColors':
-        colors = map_scalars(mapper, dataset.point_data.active_scalars)
+        colors = map_scalars(lookup_table, dataset.point_data.active_scalars)
         attr['color'] = array_to_float_buffer(colors)
 
     geo = tjs.BufferGeometry(attributes=attr)
 
+    color = pv.Color(prop.GetColor()).hex_rgb if color is None else color
+    opacity = prop.GetOpacity() if opacity is None else opacity
     m_attr = {
-        'color': pv.Color(prop.GetColor()).hex_rgb,
+        'color': color,
         'size': prop.GetPointSize() / 100,
         'vertexColors': coloring,
+        'opacity': opacity,
+        'transparent': opacity < 1.0,
     }
 
     point_mat = tjs.PointsMaterial(**m_attr)
@@ -391,25 +431,30 @@ def extract_lights_from_renderer(renderer):
     return [pvlight_to_threejs_light(pvlight) for pvlight in renderer.lights]
 
 
-def actor_to_mesh(actor, focal_point):
-    """Convert a VTK actor to a threejs mesh or meshes."""
-    mapper = actor.GetMapper()
-    if mapper is None:
-        return
-
-    # ignore any mappers whose inputs are not datasets
-    if not hasattr(mapper, 'GetInputAsDataSet'):
-        return
-
-    dataset = mapper.GetInputAsDataSet()
-
+def dataset_to_mesh(
+    dataset,
+    prop,
+    texture,
+    focal_point,
+    coloring,
+    scalar_mode,
+    color_mode,
+    lookup_table,
+    color=None,
+    opacity=None,
+):
+    """Convert a VTK dataset to a threejs mesh or meshes."""
     has_faces = True
     if hasattr(dataset, 'faces'):
         has_faces = np.any(dataset.faces)
 
-    prop = actor.GetProperty()
     rep_type = prop.GetRepresentationAsString()
 
+    # PolyData vertices should always be rendered
+    has_verts = False
+    if isinstance(dataset, pv.PolyData):
+        has_verts = dataset.verts.any()
+
     meshes = []
     if rep_type == 'Surface' and has_faces:
         surf = extract_surface_mesh(dataset)
@@ -418,22 +463,73 @@ def actor_to_mesh(actor, focal_point):
             # must offset polygons to have mesh render property with lines
             add_attr = {'polygonOffset': True, 'polygonOffsetFactor': 1, 'polygonOffsetUnits': 1}
 
-            meshes.append(to_edge_mesh(surf, mapper, prop, use_edge_coloring=True))
+            meshes.append(
+                to_edge_mesh(
+                    surf,
+                    prop,
+                    coloring,
+                    scalar_mode,
+                    lookup_table,
+                    use_edge_coloring=True,
+                    color=color,
+                    opacity=opacity,
+                )
+            )
 
-        meshes.append(to_surf_mesh(actor, surf, mapper, prop, add_attr))
+        meshes.append(
+            to_surf_mesh(
+                surf,
+                texture,
+                prop,
+                scalar_mode,
+                color_mode,
+                lookup_table,
+                coloring,
+                add_attr,
+                color=color,
+                opacity=opacity,
+            )
+        )
 
     elif rep_type == 'Points':
-        meshes.append(to_tjs_points(dataset, mapper, prop))
-    else:  # wireframe
+        meshes.append(
+            to_tjs_points(dataset, prop, coloring, lookup_table, color=color, opacity=opacity)
+        )
+
+    if has_verts:
+        # extract just vertices
+        poly_points = dataset.extract_cells(dataset.verts[1::2])
+        meshes.append(
+            to_tjs_points(poly_points, prop, coloring, lookup_table, color=color, opacity=opacity)
+        )
+
+    if rep_type not in ['Surface', 'Points']:
         if has_faces:
             surf = extract_surface_mesh(dataset)
-            mesh = to_edge_mesh(surf, mapper, prop, use_edge_coloring=False)
+            mesh = to_edge_mesh(
+                surf,
+                prop,
+                coloring,
+                scalar_mode,
+                lookup_table,
+                use_edge_coloring=False,
+                color=color,
+                opacity=opacity,
+            )
             meshes.append(mesh)
         elif np.any(dataset.lines):
-            mesh = to_edge_mesh(dataset, mapper, prop, use_edge_coloring=False, use_lines=True)
+            mesh = to_edge_mesh(
+                dataset,
+                prop,
+                coloring,
+                scalar_mode,
+                lookup_table,
+                use_edge_coloring=False,
+                use_lines=True,
+            )
             meshes.append(mesh)
         else:  # pragma: no cover
-            warnings.warn('Empty or unsupported dataset attached to actor')
+            warnings.warn(f'Empty or unsupported dataset {type(dataset)}.')
 
     # the camera in three.js has no concept of a "focal point".  In
     # three.js, the scene is always centered at the origin, which
@@ -446,11 +542,62 @@ def actor_to_mesh(actor, focal_point):
 
 
 def meshes_from_actors(actors, focal_point):
-    """Convert a pyvista plotter to a scene."""
+    """Convert VTK actors to threejs meshes.
+
+    Parameters
+    ----------
+    actors : list[vtk.vtkActor]
+        List of VTK actors.
+
+    focal_point : sequence
+        Length three sequence representing the focal point of the camera.
+
+    Returns
+    -------
+    list
+        List of :class:`pythreejs.Mesh`.
+
+    """
     meshes = []
     for actor in actors:
-        mesh = actor_to_mesh(actor, focal_point)
-        if mesh is not None:
+        mapper = actor.GetMapper()
+        if mapper is None:
+            continue
+
+        # ignore any mappers whose inputs are not datasets
+        if isinstance(mapper, pv.CompositePolyDataMapper):
+            prop = actor.GetProperty()
+            block_attrs = mapper.block_attr
+            for i, dataset in enumerate(mapper.dataset):
+                # individual block opacity might be different
+                block_attr = block_attrs[i + 1]
+                mesh = dataset_to_mesh(
+                    dataset,
+                    prop,
+                    None,
+                    focal_point,
+                    get_coloring(mapper, dataset),
+                    mapper.GetScalarModeAsString(),
+                    mapper.GetColorMode(),
+                    mapper.GetLookupTable(),
+                    color=block_attr.color,
+                    opacity=block_attr.opacity,
+                )
+                meshes.extend(mesh)
+        elif not hasattr(mapper, 'GetInputAsDataSet'):
+            continue
+        else:
+            dataset = pv.wrap(mapper.GetInputAsDataSet())
+            mesh = dataset_to_mesh(
+                dataset,
+                actor.GetProperty(),
+                actor.GetTexture(),
+                focal_point,
+                get_coloring(mapper, dataset),
+                mapper.GetScalarModeAsString(),
+                mapper.GetColorMode(),
+                mapper.GetLookupTable(),
+            )
             meshes.extend(mesh)
 
     return meshes
@@ -512,7 +659,7 @@ def convert_renderer(pv_renderer):
 
 def convert_plotter(pl):
     """Convert a pyvista plotter to a pythreejs widget."""
-    if not hasattr(pl, 'ren_win'):
+    if pl.render_window is None:
         raise AttributeError(
             'This plotter is closed and unable to export to html.\n'
             'Please run this before showing or closing the plotter.'
